@@ -13,29 +13,28 @@
    Copyright 2022, HSPyLib team
 """
 
-import binascii
-import contextlib
-import getpass
-import logging as log
-import os
-import shutil
-import uuid
-from typing import List
-
-import cryptocode
-import keyring
 from cryptography.fernet import InvalidToken
 from datasource.identity import Identity
 from hspylib.core.preconditions import check_not_none
 from hspylib.core.tools.commons import file_is_not_empty, safe_delete_file, syserr, sysout, touch_file
 from hspylib.modules.cache.ttl_keyring_be import TTLKeyringBE
 from hspylib.modules.security.security import b64_decode, decode_file, decrypt_file, encode_file, encrypt_file
-
+from typing import List
 from vault.core.vault_config import VaultConfig
 from vault.core.vault_service import VaultService
 from vault.entity.vault_entry import VaultEntry
 from vault.exception.exceptions import VaultCloseError, VaultExecutionException, VaultSecurityException
 
+import binascii
+import contextlib
+import cryptocode
+import getpass
+import keyring
+import logging as log
+import os
+import shutil
+import uuid
+
 
 class Vault:
     """Represents the vault and it's functionalities"""
@@ -115,9 +114,9 @@ class Vault:
                 sysout(entry.to_string())
         else:
             if filter_expr:
-                sysout(f"%YELLOW%\n-=- No results to display containing '{filter_expr}' -=-\n%NC%")
+                sysout(f"%YELLOW%%EOL%-=- No results to display containing '{filter_expr}' -=-%EOL%%NC%")
             else:
-                sysout("%YELLOW%\n-=- Vault is empty -=-\n%NC%")
+                sysout("%YELLOW%%EOL%-=- Vault is empty -=-%EOL%%NC%")
         log.debug("Vault list issued. User=%s", getpass.getuser())
 
     def add(self, key: str, hint: str | None, password: str | None) -> None:
@@ -132,9 +131,11 @@ class Vault:
                 Identity(VaultEntry.VaultId(uuid.uuid4().hex)),
                 key, key, password, hint,
             )
-            if entry := VaultEntry.prompt(entry):
+            if not hint or not password:
+                entry = VaultEntry.prompt(entry)
+            if entry:
                 self.service.save(entry)
-                sysout(f"%GREEN%\n=== Entry added ===\n\n%NC%{entry.to_string()}")
+                sysout(f"%GREEN%%EOL%=== Entry saved ===%EOL%%EOL%%NC%{entry.to_string()}")
         else:
             log.error("Attempt to add to Vault failed for key=%s", key)
             syserr(f"### Entry specified by '{key}' already exists in vault")
@@ -155,7 +156,7 @@ class Vault:
             if entry:
                 entry.password = self._encrypt_password(entry.password)
                 self.service.save(entry)
-                sysout(f"%GREEN%\n=== Entry updated ===\n\n%NC%{entry.to_string()}")
+                sysout(f"%GREEN%%EOL%=== Entry updated ===%EOL%%EOL%%NC%{entry.to_string()}")
         else:
             log.error("Attempt to update Vault failed for key=%s", key)
             syserr(f"### No entry specified by '{key}' was found in vault")
@@ -181,7 +182,7 @@ class Vault:
         entry = self.service.get_by_key(key)
         if entry:
             self.service.remove(entry)
-            sysout(f"%GREEN%\n=== Entry removed ===\n\n%NC%{entry.to_string()}")
+            sysout(f"%GREEN%%EOL%=== Entry removed ===%EOL%%EOL%%NC%{entry.to_string()}")
         else:
             log.error("Attempt to remove to Vault failed for key=%s", key)
             syserr(f"### No entry specified by '{key}' was found in vault")
