@@ -12,16 +12,15 @@
 
    Copyright 2022, HSPyLib team
 """
-import re
-from collections import namedtuple
-from textwrap import dedent
-from typing import Union, Optional
-
-from clitt.core.tui.minput.input_validator import InputValidator
 from clitt.core.tui.minput.minput import MenuInput, minput
+from collections import namedtuple
 from datasource.crud_entity import CrudEntity
 from datasource.identity import Identity
 from hspylib.core.zoned_datetime import now
+from textwrap import dedent
+from typing import Optional, Union
+
+import re
 
 
 class VaultEntry(CrudEntity):
@@ -54,14 +53,12 @@ class VaultEntry(CrudEntity):
                 .build() \
             .field() \
                 .label('Hint') \
-                .validator(InputValidator.anything()) \
                 .min_max_length(3, 50) \
                 .value(entry.hint) \
                 .build() \
             .field() \
                 .label('Password') \
                 .itype('password') \
-                .validator(InputValidator.anything()) \
                 .min_max_length(4, 50) \
                 .value(entry.password) \
                 .build() \
